@@ -3,23 +3,23 @@
 import os
 import sys
 import stat  # file permissions
-import shutil
+#import shutil
 import argparse
 from argparse import RawTextHelpFormatter
 import subprocess
 import tempfile
+# local imports
+from .init_build import init_configured_build
+import console
 
 
 def help_string():
     overview = 'This is a convenience script for auto-generating a catkin workspace.\n\n'
-    instructions = "It acts on the specified directory (or the current directory if unspecified) and creates:\n\n \
- - ./src : initialised with a catkin CMakeLists.txt and a wstool .rosinstall file.\n \
- - ./debug : for native debug temporaries\n \
- - ./debug/devel : for a native debug runtime area.\n \
- - ./debug/install : for a native debug install area.\n \
- - ./release : for native release temporaries\n \
- - ./cross-debug : for parallel cross-compiled debug temporaries\n \
- - ./cross-release : for parallel cross-compiled release temporaries\n \
+    instructions = " \
+ - 'yujin_init_workspace ecl' : create an empty workspace in ./ecl.\n \
+ - 'yujin_init_workspace ~/ecl' : create an empty workspace in ~/ecl.\n \
+ - 'yujin_init_workspace ecl ecl.rosinstall' : populate a workspace from rosinstall file.\n \
+ - 'yujin_init_workspace ecl https://raw.github.com/stonier/ecl_core/groovy-devel/ecl.rosinstall' : populate from uri.\n \
 "
     return overview + instructions
 
@@ -37,8 +37,7 @@ def create_groovy_script(script_name):
 def parse_arguments():
     parser = argparse.ArgumentParser(description=help_string(), formatter_class=RawTextHelpFormatter)
     parser.add_argument('dir', nargs='?', default=os.getcwd(), help='directory to use for the workspace [current working directory]')
-    parser.add_argument('-c', '--cross', action='store_true', help='install cross-compiling build directories [false]')
-    parser.add_argument('-o', '--overlay', action='store', default='/opt/ros/groovy', help='directory on top of which to overlay [/opt/ros/groovy]')
+    parser.add_argument('uri', nargs='?', default=None, help='uri for a rosinstall file [None]')
     parser.add_argument('-s', '--simple', action='store_true', help='just create a basic single build workspace (usual ros style) [false]')
     args = parser.parse_args()
     return args
@@ -70,14 +69,14 @@ def read_template(tmplf):
     return t
 
 
-def fill_in_template(template, name, cwd, overlay):
+def fill_in_template(template, name, cwd):
     return template % locals()
 
 
-def instantiate_template(filename, name, cwd, overlay):
+def instantiate_template(filename, name, cwd):
     template_dir = os.path.join(os.path.dirname(__file__), 'templates', 'init_workspace')
     tmpl = read_template(os.path.join(template_dir, filename))
-    contents = fill_in_template(tmpl, name, cwd, overlay)
+    contents = fill_in_template(tmpl, name, cwd)
     try:
         f = open(os.path.join(cwd, filename), 'w')
         f.write(contents.encode('utf-8'))
@@ -86,21 +85,12 @@ def instantiate_template(filename, name, cwd, overlay):
         f.close()
 
 
-def init_cross_workspace(workspace_dir):
-    os.mkdir(os.path.join(workspace_dir, 'cross-debug'))
-    os.mkdir(os.path.join(workspace_dir, 'cross-release'))
-    template_dir = os.path.join(os.path.dirname(__file__), 'templates', 'init_workspace')
-    shutil.copy(os.path.join(template_dir, 'Makefile'), os.path.join(workspace_dir, 'cross-debug'))
-    shutil.copy(os.path.join(template_dir, 'Makefile-Release'), os.path.join(workspace_dir, 'cross-release', 'Makefile'))
-
-
 def init_workspace():
     args = parse_arguments()
     if not which("/opt/ros/groovy/bin/catkin_init_workspace"):
         sys.exit("\nCatkin is not installed: 'sudo apt-get install ros-groovy-catkin'\n")
     if not which("wstool"):
         sys.exit("\nThe workspace tool is not installed: 'sudo apt-get install python-wstool'\n")
-    print args.dir
     if os.path.isabs(args.dir):
         workspace_dir = args.dir
     else:
@@ -109,32 +99,29 @@ def init_workspace():
         os.mkdir(workspace_dir)
     if os.path.isdir(os.path.join(workspace_dir, 'src')):
         sys.exit("This workspace is already initialised")
-
+    if args.uri:
+        uri = args.uri  # assume its an absolute path or http uri
+        if not os.path.isabs(args.uri):
+            if os.path.isfile(os.path.join(os.getcwd(), args.uri)):
+                uri = os.path.join(os.getcwd(), args.uri)
+    else:
+        uri = ""
+    console.pretty_println("Creating a workspace in " + workspace_dir, console.bold)
     os.mkdir(os.path.join(workspace_dir, 'src'))
     os.chdir(os.path.join(workspace_dir, 'src'))
-    os.system('wstool init . ' + args.overlay)
+    if uri:
+        os.system('wstool init . ' + uri)
+        # os.system('wstool update') Not needed if adding the uri to wstool init
+    else:
+        os.system('wstool init . ')
     catkin_init_workspace = create_groovy_script('catkin_init_workspace')
     unused_process = subprocess.call(catkin_init_workspace.name, shell=True)
     os.chdir(workspace_dir)
 
-    template_dir = os.path.join(os.path.dirname(__file__), 'templates', 'init_workspace')
-
-    if not args.simple:
-        # Create build directories
-        os.mkdir(os.path.join(workspace_dir, 'debug'))
-        os.mkdir(os.path.join(workspace_dir, 'release'))
-        if args.cross:
-            init_cross_workspace(workspace_dir)
-        shutil.copy(os.path.join(template_dir, 'Makefile'), os.path.join(workspace_dir, 'debug'))
-        shutil.copy(os.path.join(template_dir, 'Makefile-Release'), os.path.join(workspace_dir, 'release', 'Makefile'))
-
-    name = os.path.basename(workspace_dir)
-    #shutil.copy(os.path.join(template_dir, 'setup.bash'), workspace_dir)
-    instantiate_template('setup.bash', name, workspace_dir, args.overlay)
-    os.chmod(os.path.join(workspace_dir, 'setup.bash'), stat.S_IRWXU)
-    instantiate_template('.bashrc', name, workspace_dir, args.overlay)
-    instantiate_template('konsole', name, workspace_dir, args.overlay)
-    instantiate_template('gnome-terminal', name, workspace_dir, args.overlay)
-    instantiate_template('eclipse', name, workspace_dir, args.overlay)
+    if args.simple:
+        console.pretty_println("Auto creating a special build directory", console.cyan)
+        init_configured_build()
+    else:
+        console.pretty_println("Done - add source directories with `wstool` and configure parallel build dirs with 'yujin_init_build'.", console.cyan)
 
     os.unlink(catkin_init_workspace.name)
